
DROP TABLE IF EXISTS forum;
DROP TABLE IF EXISTS osobkonf;
DROP TABLE IF EXISTS konfskup;
DROP TABLE IF EXISTS konference;
DROP TABLE IF EXISTS uziv;
DROP TABLE IF EXISTS skupina;

CREATE TABLE skupina
    (
    id_skup INT UNSIGNED NOT NULL AUTO_INCREMENT,
    nazev VARCHAR(80) COLLATE latin2_general_ci DEFAULT 'Nazev skupiny',
    homepage VARCHAR(80) COLLATE latin2_general_ci DEFAULT 'Neexistuje domovska stranka',
    menu_zkr VARCHAR(50) COLLATE latin2_general_ci DEFAULT '',
    PRIMARY KEY (id_skup)
    ) ENGINE=InnoDB DEFAULT CHARSET=latin2 COLLATE=latin2_general_ci;

CREATE TABLE uziv
    (
    uid INT UNSIGNED NOT NULL AUTO_INCREMENT,
    uname VARCHAR(32) COLLATE latin2_general_ci NOT NULL DEFAULT '',
    datlog DATETIME DEFAULT NULL,
    PRIMARY KEY  (uid)
    ) ENGINE=InnoDB DEFAULT CHARSET=latin2 COLLATE=latin2_general_ci;

CREATE TABLE konference
    (
    id_konf INT UNSIGNED NOT NULL AUTO_INCREMENT,
    id_uziv INT UNSIGNED NOT NULL,
    zkratka VARCHAR(10) COLLATE latin2_general_ci DEFAULT '',
    rok INT(4) DEFAULT '',
    nazev VARCHAR(100) COLLATE latin2_general_ci,
    homepage VARCHAR(100) DEFAULT '',
    stat VARCHAR(30) COLLATE latin2_general_ci DEFAULT '',
    mesto VARCHAR(60) COLLATE latin2_general_ci DEFAULT '',
    dat_vlozeni TIMESTAMP NOT NULL,
    dat_zacatek DATE NOT NULL,
    dat_konec DATE NOT NULL,
    deadline DATE,
    notification DATE ,
    finalversion DATE ,
    popis TEXT DEFAULT '',
    archiv TINYINT(1) DEFAULT '0' NOT NULL,
    INDEX idx_konference_id_uziv (id_uziv),
    CONSTRAINT konf2uziv FOREIGN KEY (id_uziv) REFERENCES uziv(uid),
    PRIMARY KEY (id_konf)
    ) ENGINE=InnoDB DEFAULT CHARSET=latin2 COLLATE=latin2_general_ci;

-- konfercence muze patrit do vice skupin
CREATE TABLE konfskup
    (
    id_konf INT UNSIGNED NOT NULL,
    id_skup INT UNSIGNED NOT NULL,
    INDEX idx_konfskup_id_konf (id_konf),
    INDEX idx_konfskup_id_skup (id_skup),
    CONSTRAINT konfskup2konf FOREIGN KEY (id_konf) REFERENCES konference(id_konf),
    CONSTRAINT konfskup2skup FOREIGN KEY (id_skup) REFERENCES skupina(id_skup)
    ) ENGINE=InnoDB DEFAULT CHARSET=latin2 COLLATE=latin2_general_ci;

CREATE TABLE osobkonf
    (
    priorita SMALLINT NOT NULL,
    id_konf INT UNSIGNED NOT NULL,
    id_uziv INT UNSIGNED NOT NULL,
    posprispevku INT(11) NOT NULL default '0',
    priprispevku INT(11) NOT NULL default '0',
    INDEX idx_oskonference_id_konf (id_konf),
    INDEX idx_oskonference_id_uziv (id_uziv),
    CONSTRAINT osobkonf2konf FOREIGN KEY (id_konf) REFERENCES konference(id_konf),
    CONSTRAINT osobkonf2uziv FOREIGN KEY (id_uziv) REFERENCES uziv(uid)
    ) ENGINE=InnoDB DEFAULT CHARSET=latin2 COLLATE=latin2_general_ci;

CREATE TABLE forum
    (
    id_item INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
    id_reply INT(10) UNSIGNED NOT NULL,
    id_konf INT(10) UNSIGNED NOT NULL,
    id_uziv INT(10) UNSIGNED NOT NULL,
    dat_vlozeni DATETIME,
    nazev VARCHAR(50) COLLATE latin2_general_ci,
    text TEXT DEFAULT '',
    CONSTRAINT forum2konf FOREIGN KEY (id_konf) REFERENCES konference(id_konf),
    CONSTRAINT forum2uziv FOREIGN KEY (id_uziv) REFERENCES uziv(uid),
    PRIMARY KEY (id_item)
    ) ENGINE=InnoDB DEFAULT CHARSET=latin2 COLLATE=latin2_general_ci;
